SystemOrganization addCategory: #'System-Platforms'!

Object subclass: #OSPlatform
	instanceVariableNames: ''
	classVariableNames: 'Current'
	poolDictionaries: ''
	category: 'System-Platforms'!

!OSPlatform commentStamp: 'michael.rueger 2/25/2009 18:26' prior: 0!
An OSPlatform is an abstract representation of a 'OS platform'.
Platforms can be hierarchical, e.g., a "general" platform as superclass and more specific platforms as subclasses as long as the subclasses provide sufficient means to identify themselves.
The original implementation was for Tweak.

Current		holds the current OSPlatform subclass
!

OSPlatform subclass: #MacOSXPlatform
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Platforms'!

!MacOSXPlatform class methodsFor: 'private' stamp: 'sd 3/21/2009 13:52'!
isActivePlatform
	^SmalltalkImage current platformName = 'Mac OS' and:[SmalltalkImage current osVersion asNumber >= 1000]! !

!MacOSXPlatform methodsFor: 'accessing' stamp: 'michael.rueger 2/25/2009 18:18'!
platformFamily
	^#MacOSX! !

!OSPlatform class methodsFor: 'accessing' stamp: 'ar 12/11/2004 23:04'!
current
	"Answer the current platform"
	^Current! !

!OSPlatform class methodsFor: 'private' stamp: 'michael.rueger 2/25/2009 18:20'!
determineActivePlatformStartingAt: parentClass
	"Determine the current platform starting at parentClass.
	This is a potentially recursive process as we want to determine the most specific (in terms of subclasses) platform available."
	"OSPlatform determineActivePlatformStartingAt: OSPlatform"

	| platformClass |
	parentClass subclasses isEmpty
		ifTrue: [^parentClass].

	"Look for the matching platform class"
	platformClass := parentClass allSubclasses detect:[:any| any isActivePlatform] ifNone:[nil].

	"Check if there is a more specific subclass"
	^self determineActivePlatformStartingAt: platformClass! !

!OSPlatform class methodsFor: 'class initialization' stamp: 'ar 12/11/2004 22:48'!
initialize	"OSPlatform initialize"
	"Initialize the receiver"
	Smalltalk addToStartUpList: self.
	Smalltalk addToShutDownList: self.
	self startUp: true.! !

!OSPlatform class methodsFor: 'private' stamp: 'ar 12/11/2004 22:22'!
isActivePlatform
	"Answer whether the receiver is the active platform"
	^false! !

!OSPlatform class methodsFor: 'class initialization' stamp: 'ar 12/11/2004 22:49'!
shutDown: quitting
	"The system is going down"
	Current ifNotNil:[Current shutDown: quitting].
! !

!OSPlatform class methodsFor: 'class initialization' stamp: 'michael.rueger 2/25/2009 18:20'!
startUp: resuming
	"Determine the current platform.
	Use the most specific (in terms of subclasses) platform available."

	| platformClass |
	"Look for the matching platform class"
	platformClass := self determineActivePlatformStartingAt: self.
	platformClass
		ifNil: [^self].
	Current := platformClass new.
	Current startUp: resuming! !

!OSPlatform methodsFor: 'accessing' stamp: 'michael.rueger 2/25/2009 18:18'!
platformFamily
	"Returns a symbol specific to the platform family (MacOSX, Windows, Unix, RiscOS).
	This may need to be extended if there are new platforms added or significant differences within a platform family arise (as was the case between MacOS 9 and X)."

	self subclassResponsibility! !

!OSPlatform methodsFor: 'accessing' stamp: 'michael.rueger 2/25/2009 18:15'!
platformID
	self subclassResponsibility! !

!OSPlatform methodsFor: 'initialize' stamp: 'ar 12/11/2004 22:47'!
shutDown: quitting
	"Squeak is shutting down. If this platform requires specific shutdown code, this is a great place to put it."
! !

!OSPlatform methodsFor: 'initialize' stamp: 'michael.rueger 2/25/2009 18:11'!
startUp: resuming
	"Squeak is starting up. If this platform requires specific intialization, this is a great place to put it."
! !

OSPlatform subclass: #RiscOSPlatform
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Platforms'!

!RiscOSPlatform classSide methodsFor: 'private' stamp: 'michael.rueger 2/25/2009 18:22'!
isActivePlatform
	^SmalltalkImage current platformName = 'RiscOS'! !

!RiscOSPlatform methodsFor: 'accessing' stamp: 'michael.rueger 2/25/2009 18:18'!
platformFamily
	^#RiscOS! !

OSPlatform subclass: #UnixPlatform
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Platforms'!

!UnixPlatform class methodsFor: 'private' stamp: 'michael.rueger 2/25/2009 18:22'!
isActivePlatform
	^SmalltalkImage current platformName = 'unix'! !

!UnixPlatform methodsFor: 'accessing' stamp: 'michael.rueger 2/25/2009 18:18'!
platformFamily
	^#Unix! !

OSPlatform subclass: #Win32Platform
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Platforms'!

!Win32Platform class methodsFor: 'private' stamp: 'michael.rueger 2/25/2009 18:22'!
isActivePlatform
	"Answer whether the receiver is the active platform"
	^SmalltalkImage current platformName = 'Win32'! !

!Win32Platform methodsFor: 'accessing' stamp: 'michael.rueger 2/25/2009 18:18'!
platformFamily
	^#Windows! !
OSPlatform initialize!
